atomate.vasp.tests package — atomate 0.3 documentation

# atomate.vasp.tests package

## Submodules

## atomate.vasp.tests.test_copy module

class `atomate.vasp.tests.test_copy.` `TestCopyVaspOutputs`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()
  classmethod `setUpClass`()
  `tearDown`()
  `test_gzip_copy`()
  `test_plain_copy`()
  `test_plain_copy_more`()
  `test_relax2_copy`()
  `test_unittestsetup`()

## atomate.vasp.tests.test_drones module

class `atomate.vasp.tests.test_drones.` `VaspToDbTaskDroneTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  classmethod `setUpClass`()
  `test_assimilate`()
  `test_bandstructure`()
  `test_runs_assimilate`()

## atomate.vasp.tests.test_setup module

class `atomate.vasp.tests.test_setup.` `TestSetup`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()
  classmethod `setUpClass`()
  `tearDown`()
  `test_setup`()

## atomate.vasp.tests.test_vasp_powerups module

class `atomate.vasp.tests.test_vasp_powerups.` `TestVaspPowerups`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  classmethod `setUpClass`()
  `test_add_priority`()
  `test_add_small_gap_multiply`()
  `test_add_tags`()
  `test_add_trackers`()
  `test_custodian_powerups`()
  `test_modify_incar`()
  `test_use_scratch_dir`()

## atomate.vasp.tests.test_vasp_workflows module

class `atomate.vasp.tests.test_vasp_workflows.` `TestVaspWorkflows`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()
  classmethod `setUpClass`()
  `tearDown`()
  `test_bandgap_check_Vasp`()
  `test_bandstructure_Vasp`()
  `test_single_Vasp`()
  `test_single_Vasp_dbinsertion`()
  `test_trackers`()

## atomate.vasp.tests.test_write_vasp module

class `atomate.vasp.tests.test_write_vasp.` `TestWriteVasp`(methodName='runTest')

  Bases: `pymatgen.util.testing.PymatgenTest`

  `setUp`()
  classmethod `setUpClass`()
  `tearDown`()
  `test_ioset_explicit`()
  `test_ioset_implicit`()
  `test_ioset_params`()
  `test_modifyincar`()
  `test_pmgobjects`()

## Module contents